@@ -653,7 +653,8 @@ class PressureTimeseries(MetTimeseries):
                             vortex_signal + self.data_trend
 
                     # Make new object
-                    new_mt = MetTimeseries(self.time, synthetic_time_series)
+                    new_mt = PressureTimeseries(self.time, 
+                            synthetic_time_series)
                     new_mt.detrend_timeseries_boxcar(self.window_width)
 
                     new_mt.apply_lorentzian_matched_filter(
